@@ -14,7 +14,7 @@ restriktor <- function(object, constraints = NULL, ...) {
   arguments <- list(...)
   if (length(arguments)) {
     pnames <- c("se", "B", "rhs", "neq", "mix.weights", "mix.bootstrap", "parallel", 
-                "ncpus", "cl", "seed", "control", "verbose", "debug")
+                "ncpus", "cl", "seed", "control", "verbose", "debug", "auto_bound")
     pm <- pmatch(names(arguments), pnames, nomatch = 0L)
     if (any(pm == 0L)) { 
       pm.idx <- which(pm == 0L)
